stalker.core.mixins.ReferenceMixin — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.mixins.ReferenceMixin

class `stalker.core.mixins.` `ReferenceMixin`(references=[], **kwargs)

  Bases: `object`

  Adds reference capabilities to the mixed in class.

  References are `stalker.core.models.Entity` instances or anything derived from it, which adds information to the attached objects. The aim of the References are generally to give more info to direct the evolution of the object.

  Parameters: | references (list of `Entity` objects.) – A list of `Entity` objects.

  `__init__`(references=[], **kwargs)

  Methods

  `__init__`(**kwargs[, references]) |

  Attributes

  `references` | References are lists containing `Entity` instances.

  `references`

    References are lists containing `Entity` instances.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »